pub struct LighterUserStatsScoped {
pub available_balance: Decimal,
pub buying_power: Decimal,
pub collateral: Decimal,
pub leverage: Decimal,
pub margin_usage: Decimal,
pub portfolio_value: Decimal,
}Expand description
Inner shape of the user_stats.stats.cross_stats and .total_stats
substructs. Every field is a stringified decimal on the wire and
denominated in USDC.
Fields
available_balance: Decimalbuying_power: Decimalcollateral: Decimalleverage: Decimalmargin_usage: Decimalportfolio_value: DecimalTrait Implementations
Sourceimpl Clone for LighterUserStatsScoped
impl Clone for LighterUserStatsScoped
Sourcefn clone(&self) -> LighterUserStatsScoped
fn clone(&self) -> LighterUserStatsScoped
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LighterUserStatsScoped
impl Debug for LighterUserStatsScoped
Sourceimpl<'de> Deserialize<'de> for LighterUserStatsScoped
impl<'de> Deserialize<'de> for LighterUserStatsScoped
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LighterUserStatsScoped
impl PartialEq for LighterUserStatsScoped
Sourcefn eq(&self, other: &LighterUserStatsScoped) -> bool
fn eq(&self, other: &LighterUserStatsScoped) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LighterUserStatsScoped
impl Serialize for LighterUserStatsScoped
impl StructuralPartialEq for LighterUserStatsScoped